@@ -2,9 +2,7 @@ from __future__ import annotations
 
 from typing import Optional
 
-import log.models
-from core.models import Tipo
-
+from django.apps import apps
 
 class InteligerMeta(type):
     _instance: Optional[Inteliger] = None
@@ -22,7 +20,8 @@ class Inteliger(metaclass=InteligerMeta):
 
     def salvar_log(self, request=None, response=None):
         if request.META.get('REMOTE_ADDR') != '127.0.0.1':
-            log.models.Log(
+            Log = apps.get_model('log', 'Log')
+            Log(
                 status_code=response.status_code,
                 reason_phrase=response.reason_phrase,
                 metodo=request.method,
@@ -33,6 +32,7 @@ class Inteliger(metaclass=InteligerMeta):
             ).save()
 
     def atualizar_tempo_query(self):
+        Tipo = apps.get_model('core', 'Tipo')
         tempo = Tipo.objects.values('nome').filter(tipo='SISTEMA.TEMPO_QUERY').order_by('-dat_insercao').first()
         try:
             self.tempo_pesquisa = int(tempo['nome']) if tempo is not None else 0
