@@ -1,4 +1,4 @@
-from log.views import Log
+from core.views import Inteliger
 
 class LogMiddleWare:
     def __init__(self, get_response):
@@ -7,5 +7,5 @@ class LogMiddleWare:
 
     def __call__(self, request):
         response = self.get_response(request)
-        Log().salvar(request=request, response=response)
+        Inteliger().log(request=request, response=response)
         return response
\ No newline at end of file
