@@ -16,4 +16,4 @@ class Profile(AbstractUser, core.models.Log):
 
     class Meta:
         #db_table = u'"core\".\"profile"'
-        db_table = u'"profile"'
\ No newline at end of file
+        db_table = 'profile'
\ No newline at end of file
